@@ -9,15 +9,17 @@ from fief_client.client import (
     FiefError,
     FiefIdTokenInvalid,
     FiefTokenResponse,
+    FiefUserInfo,
 )
 
-__version__ = "0.9.0"
+__version__ = "0.10.0"
 
 __all__ = [
     "Fief",
     "FiefAsync",
     "FiefTokenResponse",
     "FiefAccessTokenInfo",
+    "FiefUserInfo",
     "FiefError",
     "FiefAccessTokenExpired",
     "FiefAccessTokenMissingScope",
