@@ -33,6 +33,9 @@ class FiefAccessTokenInfo(TypedDict):
     access_token: str
 
 
+FiefUserInfo = Dict[str, Any]
+
+
 class FiefError(Exception):
     pass
 
@@ -154,7 +157,7 @@ class BaseFief:
         *,
         code: Optional[str] = None,
         access_token: Optional[str] = None,
-    ) -> Dict[str, Any]:
+    ) -> FiefUserInfo:
         try:
             if self.encryption_key is not None:
                 decrypted_id_token = jwt.JWT(jwt=id_token, key=self.encryption_key)
@@ -238,6 +241,21 @@ class BaseFief:
             "GET", endpoint, headers={"Authorization": f"Bearer {access_token}"}
         )
 
+    def _get_update_profile_request(
+        self,
+        client: HTTPXClient,
+        *,
+        endpoint: str,
+        access_token: str,
+        data: Dict[str, Any],
+    ) -> httpx.Request:
+        return client.build_request(
+            "PATCH",
+            endpoint,
+            headers={"Authorization": f"Bearer {access_token}"},
+            json=data,
+        )
+
 
 class Fief(BaseFief):
     def auth_url(
@@ -263,7 +281,7 @@ class Fief(BaseFief):
 
     def auth_callback(
         self, code: str, redirect_uri: str, *, code_verifier: Optional[str] = None
-    ) -> Tuple[FiefTokenResponse, Dict[str, Any]]:
+    ) -> Tuple[FiefTokenResponse, FiefUserInfo]:
         token_response = self._auth_exchange_token(
             code, redirect_uri, code_verifier=code_verifier
         )
@@ -278,7 +296,7 @@ class Fief(BaseFief):
 
     def auth_refresh_token(
         self, refresh_token: str, *, scope: Optional[List[str]] = None
-    ) -> Tuple[FiefTokenResponse, Dict[str, Any]]:
+    ) -> Tuple[FiefTokenResponse, FiefUserInfo]:
         token_endpoint = self._get_endpoint_url(
             self._get_openid_configuration(), "token_endpoint"
         )
@@ -310,7 +328,7 @@ class Fief(BaseFief):
             access_token, jwks, required_scope=required_scope
         )
 
-    def userinfo(self, access_token: str) -> Dict[str, Any]:
+    def userinfo(self, access_token: str) -> FiefUserInfo:
         userinfo_endpoint = self._get_endpoint_url(
             self._get_openid_configuration(), "userinfo_endpoint"
         )
@@ -324,6 +342,22 @@ class Fief(BaseFief):
 
             return response.json()
 
+    def update_profile(self, access_token: str, data: Dict[str, Any]) -> FiefUserInfo:
+        update_profile_endpoint = f"{self.base_url}/profile"
+
+        with self._get_httpx_client() as client:
+            request = self._get_update_profile_request(
+                client,
+                endpoint=update_profile_endpoint,
+                access_token=access_token,
+                data=data,
+            )
+            response = client.send(request)
+
+            response.raise_for_status()
+
+            return response.json()
+
     def logout_url(self, redirect_uri: str) -> str:
         params = {"redirect_uri": redirect_uri}
         return f"{self.base_url}/logout?{urlencode(params)}"
@@ -403,7 +437,7 @@ class FiefAsync(BaseFief):
 
     async def auth_callback(
         self, code: str, redirect_uri: str, *, code_verifier: Optional[str] = None
-    ) -> Tuple[FiefTokenResponse, Dict[str, Any]]:
+    ) -> Tuple[FiefTokenResponse, FiefUserInfo]:
         token_response = await self._auth_exchange_token(
             code, redirect_uri, code_verifier=code_verifier
         )
@@ -418,7 +452,7 @@ class FiefAsync(BaseFief):
 
     async def auth_refresh_token(
         self, refresh_token: str, *, scope: Optional[List[str]] = None
-    ) -> Tuple[FiefTokenResponse, Dict[str, Any]]:
+    ) -> Tuple[FiefTokenResponse, FiefUserInfo]:
         token_endpoint = self._get_endpoint_url(
             await self._get_openid_configuration(), "token_endpoint"
         )
@@ -451,7 +485,7 @@ class FiefAsync(BaseFief):
             access_token, jwks, required_scope=required_scope
         )
 
-    async def userinfo(self, access_token: str) -> Dict[str, Any]:
+    async def userinfo(self, access_token: str) -> FiefUserInfo:
         userinfo_endpoint = self._get_endpoint_url(
             await self._get_openid_configuration(), "userinfo_endpoint"
         )
@@ -465,6 +499,24 @@ class FiefAsync(BaseFief):
 
             return response.json()
 
+    async def update_profile(
+        self, access_token: str, data: Dict[str, Any]
+    ) -> FiefUserInfo:
+        update_profile_endpoint = f"{self.base_url}/profile"
+
+        async with self._get_httpx_client() as client:
+            request = self._get_update_profile_request(
+                client,
+                endpoint=update_profile_endpoint,
+                access_token=access_token,
+                data=data,
+            )
+            response = await client.send(request)
+
+            response.raise_for_status()
+
+            return response.json()
+
     async def logout_url(self, redirect_uri: str) -> str:
         params = {"redirect_uri": redirect_uri}
         return f"{self.base_url}/logout?{urlencode(params)}"
